swrfM_csf: Segmented CSF mask file used in processing the SPM auditory test data set
Description
The data set swrfM_csf.nii.gz defines the CSF mask used in fMRI analyses
for the SPM auditory data set swrfM_filtered_func_data.nii.gz.
The package's data directory includes mask files associated with the
partition of the SPM auditory data set (prefixed by fbase="swrfM"), in 3
classes: cerebrospinal fluid (CSF), grey matter (GRY) and white matter (WHT).
The segmented masks were obtained by applying FSL/FAST to the structural
high-resolution fMRI image, followed by FSL/FLIRT for low-resolution registration
(see cudaBayesreg::read.Zsegslice).
Format
The file swrfM_csf.nii.gz is in gzipped NIFTI format.References
SPM8 Manual, John Ashburner et. al., Functional Imaging Laboratory,
Institute of Neurology, UCL, London, (http://www.fil.ion.ucl.ac.uk/spm/)FSL & FreeSurfer Course, Oxford Centre for Functional Magnetic Resonance Imaging of the Brain (FMRIB), University of Oxford.
(www.fmrib.ox.ac.uk/fsl).